=======
History
=======

2023.2.28 -- Initial version!
    * Handles energy and optimization.
    * ANI-1x, ANI-1ccx, and ANI-2x models
      
2023.1.17 (2023-01-17)
    * Plug-in created using the SEAMM plug-in cookiecutter.
